#!/bin/sh
#
#  Licensed to the Apache Software Foundation (ASF) under one or more
#  contributor license agreements.  See the NOTICE file distributed with
#  this work for additional information regarding copyright ownership.
#  The ASF licenses this file to You under the Apache License, Version 2.0
#  (the "License"); you may not use this file except in compliance with
#  the License.  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


# Script to copy the tomcat source to the appropriate places in the mavenized project
# Run after running the tomcat archetype.
# Typically run from run.sh

# Figure out if the framework is already in svn
if [ -d .svn ]
then
  #yes, use svn copy to preserve history
  SVN_CMD="svn cp --parents"
  RM="svn rm"
else
  #no, use svn export to avoid polluting with svn crud
  SVN_CMD="svn export"
  RM="rm -rf"
fi

TOMCAT_BASE="https://svn.apache.org/repos/asf/tomcat/tc7.0.x/tags/TOMCAT_7_0_19/"

TOMCAT=$TOMCAT_BASE

#catalina
$SVN_CMD $TOMCAT/java/org/apache/catalina/ catalina/src/main/java/org/apache/catalina
$SVN_CMD $TOMCAT/java/org/apache/naming/ catalina/src/main/java/org/apache/naming
$RM catalina/src/main/java/org/apache/catalina/ant
$RM catalina/src/main/java/org/apache/catalina/cluster
$RM catalina/src/main/java/org/apache/catalina/ha
$RM catalina/src/main/java/org/apache/catalina/tribes
# does not exist?
$RM catalina/src/main/java/org/apache/catalina/launcher
# does not exist?
$RM catalina/src/main/java/org/apache/catalina/storeconfig
$RM catalina/src/main/java/org/apache/naming/factory/webservices
#formerly coyote jar
$SVN_CMD $TOMCAT/java/org/apache/coyote/ catalina/src/main/java/org/apache/coyote
$SVN_CMD $TOMCAT/java/org/apache/tomcat/jni/ catalina/src/main/java/org/apache/tomcat/jni
$SVN_CMD $TOMCAT/java/org/apache/jk/ catalina/src/main/java/org/apache/jk
$SVN_CMD $TOMCAT/java/org/apache/tomcat/util/net/ catalina/src/main/java/org/apache/tomcat/util/net

#catalina-ha
$SVN_CMD $TOMCAT/java/org/apache/catalina/ha/ catalina-ha/src/main/java/org/apache/catalina/ha

#coyote
#$SVN_CMD $TOMCAT/java/org/apache/coyote/ coyote/src/main/java/org/apache/coyote
#$SVN_CMD $TOMCAT/java/org/apache/tomcat/jni/ coyote/src/main/java/org/apache/tomcat/jni
#$SVN_CMD $TOMCAT/java/org/apache/jk/ coyote/src/main/java/org/apache/jk
#$SVN_CMD $TOMCAT/java/org/apache/tomcat/util/net/ coyote/src/main/java/org/apache/tomcat/util/net

#jasper
$SVN_CMD $TOMCAT/java/org/apache/jasper/ jasper/src/main/java/org/apache/jasper

#jasper-el
$SVN_CMD $TOMCAT/java/org/apache/el/ jasper-el/src/main/java/org/apache/el

#jasper-jdt appears to be a shade

#juli
$SVN_CMD $TOMCAT/java/org/apache/juli/ juli/src/main/java/org/apache/juli



#shared
if [ -d .svn ]
then
  $SVN_CMD $TOMCAT/java/org/apache/tomcat/InstanceManager.java shared/src/main/java/org/apache/tomcat/InstanceManager.java
  $SVN_CMD $TOMCAT/java/org/apache/tomcat/JarScanner.java shared/src/main/java/org/apache/tomcat
  $SVN_CMD $TOMCAT/java/org/apache/tomcat/JarScannerCallback.java shared/src/main/java/org/apache/tomcat
  $SVN_CMD $TOMCAT/java/org/apache/tomcat/PeriodicEventListener.java shared/src/main/java/org/apache/tomcat
else
  $SVN_CMD -N $TOMCAT/java/org/apache/ shared/src/main/java/org/apache
fi

#tribes
$SVN_CMD $TOMCAT/java/org/apache/catalina/tribes/ tribes/src/main/java/org/apache/catalina/tribes

#util
$SVN_CMD $TOMCAT/java/org/apache/tomcat/util/ util/src/main/java/org/apache/tomcat/util
$RM util/src/main/java/org/apache/tomcat/util/net

# move the properties files to src/main/resourcs
find . -name *.properties |xargs -n1 ./mv-resource.sh

# move the mbean descriptor xml files to src/main/resourcs
find . -name mbeans-descriptors.??? |xargs -n1 ./mv-resource.sh
